==> scripts-1.5.9-y.1.tgz: package/spaConfig/webpack.prod.js <==
const { merge } = require('webpack-merge');
const TerserPlugin = require('terser-webpack-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const { getProjectPath, deleteFolders } = require('../common/utils');
const baseConfig = require('./webpack.base');

module.exports = function (appConfig, extendEnv) {
  const result = merge(baseConfig(true, appConfig, extendEnv), {
    // 打包的入口文件
    entry: getProjectPath('/src/index.tsx'),
    // 打包的出口
    output: {
      publicPath: '/',
      path: getProjectPath('/build'),
      // 入口文件生产的js
      filename: `js/[name].chunk.js?v=${extendEnv.version}`,
      // 非入口文件生产的js
      chunkFilename: `js/[name].chunk.js?v=${extendEnv.version}`
    },
    optimization: {
      // 在不同的编译中不变的短数字id。有益于长期缓存。在生产模式中会默认开启。
      chunkIds: 'deterministic',
      concatenateModules: true,
      minimizer: [
        // 压缩js
        new TerserPlugin({
          terserOptions: {
            parse: {
              ecma: 8
            },
            compress: {
              ecma: 5,
              warnings: false,
              comparisons: false,
              inline: 2
            },
            mangle: {
              safari10: true
            },
            output: {
              ecma: 5,
              comments: false,
              ascii_only: true
            }
          }
        }),
        // 压缩css
        new CssMinimizerPlugin()
      ],
      splitChunks: {
        chunks: 'async',
        minSize: 10000,
        minRemainingSize: 0,
        minChunks: 1,
        // 按需加载时的最大并行请求数。
        maxAsyncRequests: 300,
        // 入口点的最大并行请求数。
        maxInitialRequests: 300,
        enforceSizeThreshold: 50000,
        cacheGroups: {
          defaultVendors: {
            test: /[\\/]node_modules[\\/]/,
            minChunks: 2,
            name: 'vendor',
            priority: -10,
            reuseExistingChunk: true
          },
          default: {
            minChunks: 3,
            priority: -20,
            reuseExistingChunk: true
          }
        }
      },
      runtimeChunk: {
        name: 'manifest'
      }
    }
  });

  const outputPath = getProjectPath(result.output.path);
  deleteFolders(outputPath);

  return result;
};

==> scripts-1.9.4-y.1.tgz: package/spaConfig/webpack.prod.js <==
const { merge } = require('webpack-merge');
const TerserPlugin = require('terser-webpack-plugin');
const CssMinimizerPlugin = require('css-minimizer-webpack-plugin');
const { getProjectPath, deleteFolders } = require('../common/utils');
const baseConfig = require('./webpack.base');

module.exports = function (appConfig, extendEnv) {
  const result = merge(baseConfig(true, appConfig, extendEnv), {
    // 打包的入口文件
    entry: getProjectPath('/src/index.tsx'),
    // 打包的出口
    output: {
      publicPath: '/',
      path: getProjectPath('/build'),
      // 入口文件生产的js
      filename: `${appConfig.baseStaticJsPath}/[name].chunk.js?v=${extendEnv.version}`,
      // 非入口文件生产的js
      chunkFilename: `${appConfig.baseStaticJsPath}/[name].chunk.js?v=${extendEnv.version}`
    },
    optimization: {
      // 在不同的编译中不变的短数字id。有益于长期缓存。在生产模式中会默认开启。
      chunkIds: 'deterministic',
      concatenateModules: true,
      minimizer: [
        // 压缩js
        new TerserPlugin({
          terserOptions: {
            parse: {
              ecma: 8
            },
            compress: {
              ecma: 5,
              warnings: false,
              comparisons: false,
              inline: 2
            },
            mangle: {
              safari10: true
            },
            output: {
              ecma: 5,
              comments: false,
              ascii_only: true
            }
          }
        }),
        // 压缩css
        new CssMinimizerPlugin()
      ],
      splitChunks: {
        chunks: 'async',
        minSize: 10000,
        minRemainingSize: 0,
        minChunks: 1,
        // 按需加载时的最大并行请求数。
        maxAsyncRequests: 300,
        // 入口点的最大并行请求数。
        maxInitialRequests: 300,
        enforceSizeThreshold: 50000,
        cacheGroups: {
          defaultVendors: {
            test: /[\\/]node_modules[\\/]/,
            minChunks: 2,
            name: 'vendor',
            priority: -10,
            reuseExistingChunk: true
          },
          default: {
            minChunks: 3,
            priority: -20,
            reuseExistingChunk: true
          }
        }
      },
      runtimeChunk: {
        name: 'manifest'
      }
    }
  });

  const outputPath = getProjectPath(result.output.path);
  deleteFolders(outputPath);

  return result;
};
